-- This work is licensed under a Creative Commons
-- Attribution-NonCommercial-ShareAlike 4.0 International License.
-- http://creativecommons.org/licenses/by-nc-sa/4.0

-- 2020 modifications:  Mark D. Aagaard, Nusa Zidaric

-- Mark D. Aagaard
-- Riham AlTawy
-- Guang Gong
-- Kalikinkar Mandal
-- Raghvendra Rohit
-- Marat Sattarov
-- Nusa Zidaric
-- http://uwaterloo.ca/communications-security-lab/lwc/ace


-- This is a human-readable summary of (and not a substitute for) the license. 
-- You are free to:

--     Share:  copy and redistribute the material in any medium or format
--     Adapt:  remix, transform, and build upon the material

--     The licensor cannot revoke these freedoms as long as you follow
--     the license terms.

-- Under the following terms:

--     Attribution - You must give appropriate credit, provide a link to
--     the license, and indicate if changes were made. You may do so in
--     any reasonable manner, but not in any way that suggests the
--     licensor endorses you or your use.

--     NonCommercial - You may not use the material for commercial
--     purposes.

--     ShareAlike - If you remix, transform, or build upon the material,
--     you must distribute your contributions under the same license as
--     the original.

--     No additional restrictions - You may not apply legal terms or
--     technological measures that legally restrict others from doing
--     anything the license permits.

------------------------------------------
-- control signals for DEC padding
------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use work.ace_pkg.all;
use work.ctrl_pkg.all;

entity ctrl_pad_to_en is
  port
    ( i_padding 	: in  pad_ty
    ; en_ctrl   	: out en_ty
    ; pad_ctrl   	: out padxor_ty
   );
end entity;

architecture rtl of ctrl_pad_to_en is

signal en : en_ty;
signal pad : padxor_ty;

begin

   en_ctrl 	<= en;
   pad_ctrl <= pad;

   en      <= "11111111" when i_padding = "000" else
              "10000000" when i_padding = "001" else 
              "11000000" when i_padding = "010" else
              "11100000" when i_padding = "011" else
              "11110000" when i_padding = "100" else
              "11111000" when i_padding = "101" else
              "11111100" when i_padding = "110" else
              "11111110" ;              
    
   padxors: for j in 0 to 6  generate  
  		 pad(j) <= en(j) xor  en(j+1); 
 	end generate padxors;

end architecture;